#include <hmg.ch>

Function Main
   local aTable := {}, cErr := ''
   local nLogoSeconds := 3
   public oDB := nil
   public lFontBold := .f.
   public nFontSize := 12
   public cFontName := 'Arial'
   public cDistanceUoM := ''
   public cFuelUoM := ''
   public cCurrency := ''
   public cDB := 'fuelwaredb.sqlite'
   public stdate := date()
   
   
   set century on
   set date ital
   set navigation extended 
  
   if file( cDB )
      oDB := connect2db( cDB, .f. )
      if oDB == nil
         msgstop( 'Database could not be connected!' )
         return nil
      endif
   else   
      if msgyesno( 'Database could not be found! Do you want to create a new database?' )
         CreateNewVehicleDatabase()
         if oDB == nil
            msgstop( 'New Database could not be connected!' )
            return nil
         endif
      else
         return nil
      endif   
   endif
   aTable := sql( oDB, 'select c.currency from config c', @cErr )
   if hmg_len( cErr ) > 0
      msgstop( cErr )
      return nil
   endif
   if hmg_len( aTable ) > 0
      cCurrency := aTable[ 1, 1 ]
   endif   
   aTable := sql( oDB, 'select date from txn order by date limit 1', @cErr )
   if hmg_len( cErr ) > 0
      msgstop( cErr )
      return nil
   endif
   if hmg_len( aTable ) > 0
      stdate := aTable[ 1, 1 ]
   endif   
   define window main at 0, 0 width 800 height 600 icon 'icon' title 'FuelWare - Vehicles Fuel Expenses/Reminder Manager' main nosize nomaximize on init showlogo( nLogoSeconds )
      define toolbar toolbar1 imagewidth 24 imageheight 24 flat .t. strictwidth .t. 
         button txnentry  picture 'txn' action fueltxn() tooltip 'Enter Transaction' 
         button vehmaster  picture 'car' action vehmast() tooltip 'Manage Vehicle Details' 
         button tagmanager  picture 'tag' action tagmanager() tooltip 'Manage Tag/Tag Groups' 
         button report2  picture 'report' action report() tooltip 'Show Report' separator
         button exit1  picture 'exit' action main.release() tooltip 'Exit'
      end toolbar   
      define button txn
         row 80
         col 30
         width 150
         caption "Transaction"
         tooltip 'Enter Transaction'
//         flat .t.
         fontsize 12
         fontname 'Arial'
         backcolor { 255, 255, 0 }
         fontbold .t.
         action fueltxn()
      end button
      define button vehmast
         row 120
         col 30
         width 150
         caption "Vehicle Manager"
         tooltip 'Manage Vehicle Details'
         flat .t.
         fontsize 12
         fontname 'Arial'
         backcolor { 255, 255, 0 }
         fontbold .t.
         action vehmast()
      end button
      define button tagman
         row 160
         col 30
         width 150
         caption "Tag Manager"
         tooltip 'Manage Tags/Tag Groups'
         flat .t.
         fontsize 12
         fontname 'Arial'
         backcolor { 255, 255, 0 }
         fontbold .t.
         action tagmanager()
      end button
      define button report
         row 200
         col 30
         width 150
         caption "Report"
         tooltip 'Show Report'
         flat .t.
         fontsize 12
         fontname 'Arial'
         backcolor { 255, 255, 0 }
         fontbold .t.
         action report()
      end button
      define button exit
         row 240
         col 30
         width 150
         caption "Exit"
         tooltip 'Exit'
         flat .t.
         fontsize 12
         fontname 'Arial'
         backcolor { 255, 255, 0 }
         fontbold .t.
         action main.release
      end button
      define grid reminders
         row 60
         col 210
         width 580
         height 240
         headers { 'Vehicle', 'Reminder Tag', 'Tag Group', 'Date' }
         dynamicbackcolor { { || remindercolor() }, { || remindercolor() }, { || remindercolor() }, { || remindercolor() } }
         widths { 150, 160, 120, 120 }
         justify { 0, 0, 0, 0 }
//         showheaders .f.
         fontname cFontName
         fontsize 12
         transparent .t.
//         fontbold .t.
      end grid
      define grid stat
         row 310
         col 10
         width 430
         height 230
         headers { '', '' }
         widths { 250, 150 }
         justify { 0, 1 }
         showheaders .f.
         fontname cFontName
         fontsize 12
         fontbold .f.
      end grid
      define label powered
         row 330
         col 453
         value 'Powered By:'
         width 400
         height 50
         fontname cFontName
         fontsize 16
         fontbold .t.
      end label
      define hyperlink hmgforum
         row 381
         col 540
         width 120
         fontname cFontName
         fontsize 14
         fontbold .t.
         value 'HMGForum'
         tooltip 'Click here to visit HMG Forum'
         address 'http://hmgforum.com'
         handcursor .t.
      end hyperlink
      define hyperlink sqliteorg
         row 381
         col 670
         width 120
         fontname cFontName
         fontsize 14
         fontbold .t.
         value 'SQLite'
         tooltip 'Click here to visit SQLite Homepage'
         address 'http://sqlite.org'
         handcursor .t.
      end hyperlink
      define hyperlink mailid
         row 421
         col 540
         width 220
         fontname cFontName
         fontsize 9
         fontbold .t.
         value 'srathinagiri@gmail.com'
         tooltip 'Mail to srathinagiri@gmail.com'
         address 'srathinagiri@gmail.com'
         handcursor .t.
      end hyperlink
      define image hmg
         row 381
         col 453
         width 71
         height 71
         picture 'hmg'
         stretch .t.
      end image   
      define image sqlite
         row 453
         col 453
         width 327
         height 97
         stretch .t.
         transparent .t.
         picture 'sqlite'
      end image
      define statusbar
         statusitem 'Welcome to FuelWare - click me!' action showlogo( 3 )
         date
         clock
      end statusbar
   end window
   update_statistics()
   main.center
   main.activate
Return


function update_statistics
   local aTable := {}, i := 0, cErr := ''
   main.reminders.deleteallitems()
   aTable := sql( oDB, 'select v.regno, t.tagname, tm.name, r.date from vehicles v, tags t, tagmaster tm, reminder r where r.vehicleid = v.id and r.tagid = t.tagid and t.catid = tm.catid order by r.date, v.regno', @cErr )
   if hmg_len( cErr ) == 0
      if hmg_len( aTable ) > 0
         for i := 1 to hmg_len( aTable )
            main.reminders.additem( { aTable[ i, 1 ], aTable[ i, 2 ], aTable[ i, 3 ], dtoc( aTable[ i, 4 ] ) } )
         next i
//         main.reminders.value := 1 
      endif
   endif      
   main.stat.deleteallitems
   // no. of vehicles
   aTable := sql( oDB, 'select count(*) from vehicles', @cErr )   
   if hmg_len( cErr ) == 0
      if hmg_len( aTable ) > 0
         main.stat.additem( { 'Vehicles', alltrim( aTable[ 1, 1 ] ) } )
      else
         main.stat.additem( { 'Vehicles', '0' } )
      endif
   endif      
   // no. of txns
   aTable := sql( oDB, 'select count(*) from txn', @cErr )   
   if hmg_len( cErr ) == 0
      if hmg_len( aTable ) > 0
         main.stat.additem( { 'Transactions', alltrim( aTable[ 1, 1 ] ) } )
      else
         main.stat.additem( { 'Transactions', '0' } )
      endif
   endif      
   // no. of taggroups
   aTable := sql( oDB, 'select count(*) from tagmaster', @cErr )   
   if hmg_len( cErr ) == 0
      if hmg_len( aTable ) > 0
         main.stat.additem( { 'Tag Groups', alltrim( aTable[ 1, 1 ] ) } )
      else
         main.stat.additem( { 'Tag Groups', '0' } )
      endif
   endif      
   // no. of tags
   aTable := sql( oDB, 'select count(*) from tags', @cErr )   
   if hmg_len( cErr ) == 0
      if hmg_len( aTable ) > 0
         main.stat.additem( { 'Tags', alltrim( aTable[ 1, 1 ] ) } )
      else
         main.stat.additem( { 'Tags', '0' } )
      endif
   endif      
   // no. of reminders
   aTable := sql( oDB, 'select count(*) from reminder', @cErr )   
   if hmg_len( cErr ) == 0
      if hmg_len( aTable ) > 0
         main.stat.additem( { 'Reminders', alltrim( aTable[ 1, 1 ] ) } )
      else
         main.stat.additem( { 'Reminders', '0' } )
      endif
   endif      
   // first date of transaction
   aTable := sql( oDB, 'select date from txn order by date limit 1', @cErr )
   if hmg_len( cErr ) == 0
      if hmg_len( aTable ) > 0
         main.stat.additem( { 'First Date of Entry', dtoc( aTable[ 1, 1 ] ) } )
         stdate := aTable[ 1, 1 ]
      endif
   endif      
   // last date of transaction
   aTable := sql( oDB, 'select date from txn order by date desc limit 1', @cErr )
   if hmg_len( cErr ) == 0
      if hmg_len( aTable ) > 0
         main.stat.additem( { 'Last Date of Entry', dtoc( aTable[ 1, 1 ] ) } )
      endif
   endif      
   
return nil

function remindercolor
   local nRowIndex := this.cellrowindex
   local aLineData := {}
   local dDate := date()
   local dToday := date()
   if nRowIndex > 0
      aLineData := main.reminders.item( nRowIndex )
      dDate := ctod( aLineData[ 4 ] )
      if dDate > dToday + 30 // 30 days cushion available
         return { 100, 255, 100 }
      endif   
      if dDate > dToday .and. dDate < dToday + 30 // less than 30 days cushion 
         return { 255, 255, 100 }
      endif
      if dDate <= dToday // red!!!
         return { 255, 100, 100 }
      endif
   endif
return nil          

function showlogo( nLogoSeconds )
   local iTime := Seconds()
   define image splash
      parent main
      row 207
      col 100
      picture "splash" 
      width 600
      height 187
   end image
   Do While Seconds() - iTime < nLogoSeconds
   EndDo
   main.splash.release()
return nil

